pub struct GreedyDecoder;Expand description
Always selects the token with the highest logit (argmax decoding).
Implementations
Sourceimpl GreedyDecoder
impl GreedyDecoder
Sourcepub fn decode(&self, logits: &[f64]) -> Result<SampledToken, SamplingError>
pub fn decode(&self, logits: &[f64]) -> Result<SampledToken, SamplingError>
Decode a single logit vector, returning the argmax token.
Sourcepub fn decode_batch(
&self,
logits: &[Vec<f64>],
) -> Result<Vec<SampledToken>, SamplingError>
pub fn decode_batch( &self, logits: &[Vec<f64>], ) -> Result<Vec<SampledToken>, SamplingError>
Decode a batch of logit vectors, one argmax per row.